function fadvdiffupw(c,d,L,a_left,a_right,s,dx,dt,T,interval)

% This function is called by advdiffupw.m and is used by the gui advdiffupw.fig
% For a description of the parameters look in adv-diff.inf or adv-diff-inf.tex

       
    ntstps = T/dt;

% Set up the parameters for the leap frog scheme.
%
       c2 = 2.*d*dt/(dx*dx);
       c1 = c*dt/dx;
       jmax = (2*L)/dx+1;

%  set up the initial condition

       for j = 1:jmax

         w1(j) = 0;
         w2(j) = 0;
         x(j) = -L+j*dx;

       end

       q = (a_right-a_left)/pi;  % q and r gaurantee w->a_left as x->-infinity
       r = (a_right+a_left)/2;   % and w->a_right as x->+infinity

       for j=1:jmax

         w1(j) = q*atan(s*x(j))+r;

       end

       for j=1:jmax 

         w2(j) = w1(j);

       end
       
        % For plotting
        xmax = L*1.1;
        xmin = -L*1.1;
        ymax = abs(max(a_left,a_right));
        ymin = -ymax;
        
        plot(x,w1);
        axis([xmin xmax ymin ymax]);
        pause(0.25);

       count = 0;

%  start the time iterations

       for n = 1:ntstps 

         if (c>0) 

           for j = 2:jmax-1

             w2(j) = w1(j)-c1*(w1(j)-w1(j-1))-c2*(w1(j+1)-2.*w1(j)+w1(j-1));
        % Added by TM
             w2(jmax) = w2(jmax-1);
           end  

         else

           for j = 2:jmax-1

             w2(j) = w1(j)-c1*(w1(j+1)-w1(j))-c2*(w1(j+1)-2.*w1(j)+w1(j-1));
             % Added by TM
             w2(1) = w2(2);
           end  
               
         end  


         count = count+1;

%
% Create the snapshots.

          if (count == interval)
            % For plotting
            xmax = L*1.1;
            xmin = -L*1.1;
            ymax = abs(max(a_left,a_right));
            ymin = -ymax;
               
            plot(x,w2);
            axis([xmin xmax ymin ymax]);
            pause(0.001);
            count = 0;
 
          end
%
%  Update the calculations in time
%
          for j=1:jmax
            w1(j)=w2(j);
          end

      end
